/** @module player/state */
import { call, put, takeEvery } from 'redux-saga/effects'
import { generatePlayerList } from './functions'

/**
 * state.js
 *
 * Collection of everything which has to do with state changes.
 **/

/** actionTypes define what actions are handeled by the reducer. */
export const actions = {
  setState: players => {
    return {
      type: 'SET_PLAYERS',
      players
    }
  },
  fileUploadStart: file => {
    return {
      type: 'PLAYER_FILE_UPLOAD_START',
      file
    }
  },
  fileUploadSuccess: allPlayers => {
    return {
      type: 'PLAYER_FILE_UPLOAD_SUCCESS',
      allPlayers
    }
  },
  fileUploadFailure: error => {
    return {
      type: 'PLAYER_FILE_UPLOAD_FAILURE',
      alert: { type: 'warning', text: error.toString() }
    }
  }
}
console.log('State actions', actions)

/** state definition */
export const state = {
  allPlayers: [],
  filteredPlayers: [],
  filters: {},
  fileUpload: 'idle',
  file: null
}
console.log('State state', state)

/** reducer is called by the redux dispatcher and handles all component actions */
export function reducer (state = [], action) {
  switch (action.type) {
    case 'SET_PLAYERS':
      return { ...state, allPlayers: action.players }
    case 'PLAYER_FILE_UPLOAD_START':
      return { ...state, fileUpload: 'started', file: action.file }
    case 'PLAYER_FILE_UPLOAD_SUCCESS':
      return { ...state, fileUpload: 'finished', allPlayers: action.allPlayers }
    case 'PLAYER_FILE_UPLOAD_FAILURE':
      return { ...state, fileUpload: 'failure' }
    default:
      return state
  }
}

function * uploadFile (action) {
  try {
    console.log('PlayerList uploadFile', action.file)
    const allPlayers = yield call(generatePlayerList, action.file)
    console.log('PlayerList success!', actions.fileUploadSuccess(allPlayers))
    yield put(actions.fileUploadSuccess(allPlayers))
  } catch (error) {
    console.log('PlayerList failure!', actions.fileUploadFailure(error))
    yield put(actions.fileUploadFailure(error))
  }
}

/** sagas are asynchronous workers (JS generators) to handle the state. */
export function * saga () {
  console.log('Player saga started.')
  yield takeEvery('PLAYER_FILE_UPLOAD_START', uploadFile)
}
